import React, { useState, useRef, useEffect } from 'react';
import { Popover } from 'antd';
import classNames from 'classnames';
import s from './index.less';
import extendIcon from '../../../../assets/extend.png';

export const Tags = (props: any) => {
    const { value, origin, componentAttr } = props;
    if (!Array.isArray(value) || value.length === 0) return null;
    const { options, mode } = componentAttr || {};
    const [dotVisible, setDotVisible] = useState(false);
    const outer = useRef(null);
    const inner = useRef(null);
    useEffect(() => {
        const outerTarget: any = outer.current;
        const innerTarget: any = inner.current;
        if (outerTarget && innerTarget && origin !== 'detailForm') {
            if (innerTarget.clientWidth > outerTarget.clientWidth) {
                setDotVisible(true);
            } else {
                setDotVisible(false);
            }
        }
    }, [value]);

    const outStyle: any = {};
    const innerStyle: any = {};
    const itemStyle: any = {};
    if (origin === 'detailForm') {
        outStyle.width = 'auto';
        innerStyle.flexWrap = 'wrap';
        itemStyle.marginBottom = '5px';
    }
    return (
        <div className={s.container}>
            <div className={s.outContainer} ref={outer} style={outStyle}>
                <div className={s.innerContainer} ref={inner} style={innerStyle}>
                    {value.map((item, index) => {
                        let color = '';
                        if (options && Array.isArray(options) && options.length > 0) {
                            const obj = options.find((ls) => ls.id === item.value) || {};
                            color = obj.color || 'e9eef9';
                        }
                        return (
                            <span
                                key={index}
                                className={mode === 'multiple' ? classNames(s.item, s.multi) : s.item}
                                style={{ ...itemStyle, background: `#${color}` }}
                            >
                                <div className={s.itemBgTxt}>{item.text}</div>
                            </span>
                        );
                    })}
                </div>
            </div>
            {dotVisible && (
                <Popover
                    trigger="click"
                    onClick={(e) => {
                        e.stopPropagation();
                    }}
                    placement="left"
                    overlayClassName={s.popContainer}
                    content={
                        <div
                            className={s.popContent}
                            onClick={(e) => {
                                e.stopPropagation();
                            }}
                        >
                            {value.map((item, index) => {
                                let color = '';
                                if (options && Array.isArray(options) && options.length > 0) {
                                    const obj = options.find((ls) => ls.id === item.value) || {};
                                    color = obj.color || 'e9eef9';
                                }
                                return (
                                    <span className={s.popItem} key={index} style={{ background: `#${color}` }}>
                                        <div className={s.popItemBgTxt}>{item.text}</div>
                                    </span>
                                );
                            })}
                        </div>
                    }
                >
                    <div className={s.moreBtn}>
                        <img alt="" className={s.extend} src={extendIcon} />
                    </div>
                </Popover>
            )}
        </div>
    );
};
export default Tags;
